Learn R Programming

tobit1 (version 0.1-3)

broom: broom's methods

Description

Methods to compute extract in a tidy way the elements of a fitted model

Usage

# S3 method for tobit1
tidy(x, conf.int = FALSE, conf.level = 0.95, ...)

# S3 method for tobit1 glance(x, ...)

Arguments

x

a model fitted with mhurdle

conf.int, conf.level

current see generics::tidy (currently unused)

...

further arguments, currently unused

Value

tidy returns a data frame containing the estimates, their standard errors, the Student statistic and the p-value. glance returns a one line data frame containg goodness of fit measures.

Details

mhurdle exports the generics::tidy and generics::glance functions. The specific method provided for mhurdle objects enables the use of some package that relies on these functions (modelsummary for example)