Learn R Programming

tobit1 (version 0.1-3)

haustest: Hausman test

Description

Hausman test

Usage

haustest(x, y, omit = NULL)

Arguments

x

the first model,

y

the second model

omit

a character containing the effects that are removed from the test

Value

a list with class 'htest' containing the following components:

  • data.mane: a character string describing the fitted model

  • statistic: the value of the test statistic

  • parameter: degrees of freedom

  • p.value: the p.value of the test

  • method: a character indicating what type of test is performed

  • alternative: a character indicating the alternative hypothesis

References

HAUS:78tobit1

Examples

Run this code
# NOT RUN {
charitable <- dplyr::mutate(charitable,
                            logdon = log(donation) - log(25))
char_form <- logdon ~ log(donparents) + log(income) +
    education + religion + married + south
ml <- tobit1(char_form, data = charitable)
scls <- update(ml, method = "trimmed")
haustest(scls, ml, omit = "(Intercept)")
# }

Run the code above in your browser using DataLab