Methods to compute extract in a tidy way the elements of a fitted model
# S3 method for tobit1
tidy(x, conf.int = FALSE, conf.level = 0.95, ...)# S3 method for tobit1
glance(x, ...)
a model fitted with mhurdle
current see generics::tidy (currently
unused)
further arguments, currently unused
tidy returns a data frame containing the estimates,
their standard errors, the Student statistic and the
p-value. glance returns a one line data frame containg
goodness of fit measures.
mhurdle exports the generics::tidy and
generics::glance functions. The specific method provided for
mhurdle objects enables the use of some package that relies
on these functions (modelsummary for example)